chicken_turtle_util.path
========================

.. automodule:: chicken_turtle_util.path

.. autosummary::
   :nosignatures:

   chmod
   digest
   read
   remove
   write

.. autofunction:: chmod
.. autofunction:: digest
.. autofunction:: read
.. autofunction:: remove
.. autofunction:: write
